==> haskell-enclosed-exceptions-1.0.2-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.2
id: enclosed-exceptions-1.0.2-JcZ37tQ1qhnH4uOPZVXgh6
key: enclosed-exceptions-1.0.2-JcZ37tQ1qhnH4uOPZVXgh6
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: f9bbae31e18c8d75bb8d631a2ebe3407
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.4.3/site-local/enclosed-exceptions-1.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/enclosed-exceptions-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/enclosed-exceptions-1.0.2
hs-libraries: HSenclosed-exceptions-1.0.2-JcZ37tQ1qhnH4uOPZVXgh6
depends:
    base-4.11.1.0 transformers-0.5.5.0
    lifted-base-0.2.3.12-1IwFdDP2ED9JKP0164zYc7
    monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI deepseq-1.4.3.0
    transformers-base-0.4.5.2-8WC7bFFnNGCEYZMgQnFBlc
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             lifted-base-0.2.3.12-1IwFdDP2ED9JKP0164zYc7=12c7f035fe5903fd9c2f6bed0a48552c
             monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI=1f75827c7503f69e21680c4f5fdd5ce1
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             transformers-base-0.4.5.2-8WC7bFFnNGCEYZMgQnFBlc=8d6025dec3e5dd700b855b90a1ac9ead
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.3
id: enclosed-exceptions-1.0.3-En4BHSpyJM57D5xwzi2WmH
key: enclosed-exceptions-1.0.3-En4BHSpyJM57D5xwzi2WmH
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: e7c2daf7c6b117710376b53a27284da4
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.4.3/site-local/enclosed-exceptions-1.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/enclosed-exceptions-1.0.3
hs-libraries: HSenclosed-exceptions-1.0.3-En4BHSpyJM57D5xwzi2WmH
depends:
    base-4.11.1.0 transformers-0.5.5.0
    lifted-base-0.2.3.12-BrYri3LWM9pJ2tWeaR9lDb
    monad-control-1.0.2.3-87lWNcomfXpJ29QmdQvcek deepseq-1.4.3.0
    transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             lifted-base-0.2.3.12-BrYri3LWM9pJ2tWeaR9lDb=d644bc8a6ccaa6c52fce0344d0467249
             monad-control-1.0.2.3-87lWNcomfXpJ29QmdQvcek=4701eb7c70a10f72aec80f45872b6148
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ=ff843a556414f5766b414ccfa8c6dff6
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
